@@ -29,6 +29,7 @@ from narwhals._utils import (
     generate_temporary_column_name,
     parse_columns_to_drop,
     scale_bytes,
+    zip_strict,
 )
 from narwhals.dependencies import is_pandas_like_dataframe
 from narwhals.exceptions import InvalidOperationError, ShapeError
@@ -47,6 +48,7 @@ if TYPE_CHECKING:
     from narwhals._pandas_like.group_by import PandasLikeGroupBy
     from narwhals._pandas_like.namespace import PandasLikeNamespace
     from narwhals._translate import IntoArrowTable
+    from narwhals._typing import _EagerAllowedImpl, _LazyAllowedImpl
     from narwhals._utils import Version, _LimitedContext
     from narwhals.dtypes import DType
     from narwhals.typing import (
@@ -150,8 +152,8 @@ class PandasLikeDataFrame(
 
         implementation = context._implementation
         ns = implementation.to_native_namespace()
-        Series = cast("type[pd.Series[Any]]", ns.Series)  # noqa: N806
-        DataFrame = cast("type[pd.DataFrame]", ns.DataFrame)  # noqa: N806
+        Series = cast("type[pd.Series[Any]]", ns.Series)
+        DataFrame = cast("type[pd.DataFrame]", ns.DataFrame)
         aligned_data: dict[str, pd.Series[Any] | Any] = {}
         left_most: PandasLikeSeries | None = None
         for name, series in data.items():
@@ -200,7 +202,7 @@ class PandasLikeDataFrame(
         from narwhals.schema import Schema
 
         implementation = context._implementation
-        DataFrame: Constructor = implementation.to_native_namespace().DataFrame  # noqa: N806
+        DataFrame: Constructor = implementation.to_native_namespace().DataFrame
         if isinstance(schema, (Mapping, Schema)):
             it: Iterable[DTypeBackend] = (
                 get_dtype_backend(native_type, implementation)
@@ -488,9 +490,21 @@ class PandasLikeDataFrame(
             validate_column_names=False,
         )
 
+    def top_k(self, k: int, *, by: Iterable[str], reverse: bool | Sequence[bool]) -> Self:
+        df = self.native
+        schema = self.schema
+        if isinstance(reverse, bool) and all(schema[x].is_numeric() for x in by):
+            if reverse:
+                return self._with_native(df.nsmallest(k, by))
+            return self._with_native(df.nlargest(k, by))
+        return self._with_native(
+            df.sort_values(list(by), ascending=reverse).head(k),
+            validate_column_names=False,
+        )
+
     # --- convert ---
     def collect(
-        self, backend: Implementation | None, **kwargs: Any
+        self, backend: _EagerAllowedImpl | None, **kwargs: Any
     ) -> CompliantDataFrameAny:
         if backend is None:
             return PandasLikeDataFrame(
@@ -561,7 +575,7 @@ class PandasLikeDataFrame(
         )
         extra = [
             right_key if right_key not in self.columns else f"{right_key}{suffix}"
-            for left_key, right_key in zip(left_on, right_on)
+            for left_key, right_key in zip_strict(left_on, right_on)
             if right_key != left_key
         ]
         # NOTE: Keep `inplace=True` to avoid making a redundant copy.
@@ -758,7 +772,7 @@ class PandasLikeDataFrame(
         )
 
     # --- lazy-only ---
-    def lazy(self, *, backend: Implementation | None = None) -> CompliantLazyFrameAny:
+    def lazy(self, backend: _LazyAllowedImpl | None = None) -> CompliantLazyFrameAny:
         pandas_df = self.to_pandas()
         if backend is None:
             return self
